@@ -178,6 +178,61 @@ def subcommand_load(args):
                 logger.error('%s not found.' % configfile)
 
 
+def subcommand_convert(args):
+    if args.configs:
+        if '.' in args.configs:
+            args.configs.remove('.')
+            if config.in_cwd():
+                args.configs.append(config.in_cwd()[0])
+            else:
+                print('No tmuxp configs found in current directory.')
+
+        try:
+            configfile = args.configs[0]
+        except Exception:
+            print('Please enter a config')
+
+        file_user = os.path.join(config_dir, configfile)
+        file_cwd = os.path.join(cwd_dir, configfile)
+        if os.path.exists(file_cwd) and os.path.isfile(file_cwd):
+            fullfile = os.path.normpath(file_cwd)
+            filename, ext = os.path.splitext(file_cwd)
+        elif os.path.exists(file_user) and os.path.isfile(file_user):
+
+            fullfile = os.path.normpath(file_user)
+            filename, ext = os.path.splitext(file_user)
+        else:
+            logger.error('%s not found.' % configfile)
+            return
+
+        if 'json' in ext:
+            if query_yes_no('convert to <%s> to yaml?' % (fullfile)):
+                configparser = kaptan.Kaptan()
+                configparser.import_config(configfile)
+                newfile = fullfile.replace(ext, '.yaml')
+                newconfig = configparser.export(
+                    'yaml', indent=2, default_flow_style=False
+                )
+                if query_yes_no('write config to %s?' % (newfile)):
+                    buf = open(newfile, 'w')
+                    buf.write(newconfig)
+                    buf.close()
+                    print ('written new config to %s' % (newfile))
+        elif 'yaml' in ext:
+            if query_yes_no('convert to <%s> to json?' % (fullfile)):
+                configparser = kaptan.Kaptan()
+                configparser.import_config(configfile)
+                newfile = fullfile.replace(ext, '.json')
+                newconfig = configparser.export('json', indent=2)
+                print(newconfig)
+                if query_yes_no('write config to <%s>?' % (newfile)):
+                    buf = open(newfile, 'w')
+                    buf.write(newconfig)
+                    buf.close()
+                    print ('written new config to <%s>.' % (newfile))
+
+
+
 def subcommand_attach_session(args):
     commands = []
     try:
@@ -268,10 +323,29 @@ def cli_parser():
             $ tmuxp .
 
         will check launch a ~/.pullv.yaml / ~/.pullv.json from the cwd.
+        will also check for any ./*.yaml and ./*.json.
         ''' % (cwd_dir + '/', config_dir)
     )
     load.set_defaults(callback=subcommand_load)
 
+    convert = subparsers.add_parser('convert')
+
+    convert.add_argument(
+        dest='configs',
+        nargs='*',
+        type=str,
+        default=None,
+        help='''\
+        Checks current working directory (%s) then $HOME/.tmuxp directory (%s).
+
+            $ tmuxp .
+
+        will check launch a ~/.pullv.yaml / ~/.pullv.json from the cwd.
+        will also check for any ./*.yaml and ./*.json.
+        ''' % (cwd_dir + '/', config_dir)
+    )
+    convert.set_defaults(callback=subcommand_convert)
+
     parser.add_argument('--log-level', dest='log_level', default='INFO',
                         metavar='log-level',
                         help='Log level e.g. INFO, DEBUG, ERROR')
@@ -302,8 +376,12 @@ def main():
         logger.error(e)
         sys.exit()
 
+    util.oh_my_zsh_auto_title()
+
     if args.callback is subcommand_load:
         subcommand_load(args)
+    elif args.callback is subcommand_convert:
+        subcommand_convert(args)
     elif args.callback is subcommand_attach_session:
         subcommand_attach_session(args)
     elif args.callback is subcommand_kill_session:
@@ -335,7 +413,7 @@ def complete(cline, cpoint):
     ctext = cline.replace('tmuxp ', '')
 
     commands = []
-    commands.extend(['attach-session', 'kill-session', 'load'])
+    commands.extend(['attach-session', 'kill-session', 'load', 'convert'])
 
     commands = [c for c in commands if ctext in c]
 
@@ -346,8 +424,8 @@ def complete(cline, cpoint):
         ctext = ctext.replace(args.socket_name or None, '')
 
     t = Server(
-        # socket_name=args.socket_name or None,
-        # socket_path=args.socket_path or None
+        socket_name=args.socket_name or None,
+        socket_path=args.socket_path or None
     )
 
     def session_complete(command, commands, ctext):
@@ -358,25 +436,21 @@ def complete(cline, cpoint):
             sessions = [s.get('session_name') for s in t._sessions]
             commands.extend([c for c in sessions if ctext_subargs in c])
 
-            # commands = [c for c in commands if ctext_subcommand_args in c]
-            # commands = [c for c in commands if c.startswith(ctext_subargs)]
-
     def config_complete(command, commands, ctext):
         if ctext.startswith(command + ' '):
             commands[:] = []
             ctext_subargs = ctext.replace(command + ' ', '')
             configs = []
+
+            configs += ['./' + c for c in config.in_dir(cwd_dir)]
             configs += ['./' + c for c in config.in_cwd()]
-            # configs += config.in_cwd()
             configs += [os.path.join(config_dir, c)
                         for c in config.in_dir(config_dir)]
-            # configs += config.in_dir(config_dir)
-            configs += ['./' + c for c in config.in_dir(cwd_dir)]
-            # configs += config.in_dir(cwd_dir)
             commands += [c for c in configs if c.startswith(ctext_subargs)]
 
     session_complete('attach-session', commands, ctext)
     session_complete('kill-session', commands, ctext)
     config_complete('load', commands, ctext)
+    config_complete('convert', commands, ctext)
 
     print(' \n'.join(commands))
