@@ -91,8 +91,9 @@ class SessionTest(TmuxTestCase):
 
 class SessionCleanTest(TmuxTestCase):
 
-    @unittest.skip("not working yet")
     def test_is_session_clean(self):
+        '''Session.is_clean() returns False for sessions with previous commands'''
+
         self.assertEqual(self.session.is_clean(), True)
         self.session.attached_window().attached_pane().send_keys('top')
         sleep(.4)
